<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Raffle
 * @author     David George <david.george@bluelinetechnology.com.au>
 * @copyright  2022 David George
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Blueline\Component\Raffle\Site\Controller;

\defined('_JEXEC') or die;

use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\FormController;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use Joomla\Utilities\ArrayHelper;

/**
 * Raffle class.
 *
 * @since  1.0.0
 */
class RaffleformController extends FormController
{
	/**
	 * Method to check out an item for editing and redirect to the edit form.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 *
	 * @throws  Exception
	 */
	public function edit($key = NULL, $urlVar = NULL)
	{
		$app = Factory::getApplication();

		// Get the previous edit id (if any) and the current edit id.
		$previousId = (int) $app->getUserState('com_raffle.edit.raffle.id');
		$editId     = $app->input->getInt('id', 0);

		// Set the user id for the user to edit in the session.
		$app->setUserState('com_raffle.edit.raffle.id', $editId);

		// Get the model.
		$model = $this->getModel('Raffleform', 'Site');

		// Check out the item
		if ($editId)
		{
			$model->checkout($editId);
		}

		// Check in the previous user.
		if ($previousId)
		{
			$model->checkin($previousId);
		}

		// Redirect to the edit screen.
		$this->setRedirect(Route::_('index.php?option=com_raffle&view=raffleform&layout=edit', false));
	}

	/**
	 * Method to save data.
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 * @since   1.0.0
	 */
	public function save($key = NULL, $urlVar = NULL)
	{
		// Check for request forgeries.
		$this->checkToken();

		// Initialise variables.
		$app   = Factory::getApplication();
		$model = $this->getModel('Raffleform', 'Site');

		// Get the user data.
		$data = Factory::getApplication()->input->get('jform', array(), 'array');

        $data['ip'] = $_SERVER['REMOTE_ADDR'];
        
		// Validate the posted data.
		$form = $model->getForm();

		if (!$form)
		{
			throw new \Exception($model->getError(), 500);
		}

		// Validate the posted data.
		$data = $model->validate($form, $data);

		// Check for errors.
		if ($data === false)
		{
			// Get the validation messages.
			$errors = $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++)
			{
				if ($errors[$i] instanceof \Exception)
				{
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				}
				else
				{
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}

			$input = $app->input;
			$jform = $input->get('jform', array(), 'ARRAY');

			// Save the data in the session.
			$app->setUserState('com_raffle.edit.raffle.data', $jform);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_raffle.edit.raffle.id');
			$this->setRedirect(Route::_('index.php?option=com_raffle&view=raffleform&layout=edit&id=' . $id, false));

			$this->redirect();
		}

		// Attempt to save the data.
		$return = $model->save($data);

		// Check for errors.
		if ($return === false)
		{
			// Save the data in the session.
			$app->setUserState('com_raffle.edit.raffle.data', $data);

			// Redirect back to the edit screen.
			$id = (int) $app->getUserState('com_raffle.edit.raffle.id');
			$this->setMessage(Text::sprintf('Save failed', $model->getError()), 'warning');
			$this->setRedirect(Route::_('index.php?option=com_raffle&view=raffleform&layout=edit&id=' . $id, false));
		}

		// Check in the profile.
		if ($return)
		{
			$model->checkin($return);
		}

		// Clear the profile id from the session.
		$app->setUserState('com_raffle.edit.raffle.id', null);
		
		
        $value = 0; 
        
        switch($data['number_of_tickets']) {
            case 1:
                $value = 5;
            break; 
            case 3:
                $value = 10;
            break; 
            case 5:
                $value = 15;
            break; 
            case 10:
                $value = 25;
            break; 
            case 20:
                $value = 50;
            break; 
            case 50:
                $value = 100;
            break; 
            case 100:
                $value = 200;
            break; 
            case 200:
                $value = 400;
            break; 
        }

		// Redirect to the list screen.
		$this->setMessage(Text::_("Thanks " . $data['name'] . " for purchasing " . $data['number_of_tickets'] . ' tickets for $' . $value));
		
		// Send confirmation email 
		
		$mailer = Factory::getMailer();
		
		$config = Factory::getConfig();
        $sender = array( 
            $config->get( 'mailfrom' ),
            $config->get( 'fromname' ) 
        );

        $mailer->setSender($sender);
        
        $mailer->addRecipient($data['email']);
		
		$body = "Dear " . $data['name'] . ",\n\nThanks for purchasing " . $data['number_of_tickets'] . " tickets for $" . $value . ". \n\nThe Social and Community Working Group \n\nPurchase ID: " . $return . "\nIP: " . $data['ip'];
		
        $mailer->setSubject('Raffle Ticket Purchase');
        $mailer->setBody($body);

        $send = $mailer->Send();
        if ( $send !== true ) {
            $this->setMessage('Error sending email');
        } 
		
		//$menu = Factory::getApplication()->getMenu();
		//$item = $menu->getActive();
		//$url  = (empty($item->link) ? 'index.php?option=com_raffle&view=raffles' : $item->link);
		$url  = 'index.php?option=com_raffle&view=raffles';
		$this->setRedirect(Route::_($url, false));

		// Flush the data from the session.
		$app->setUserState('com_raffle.edit.raffle.data', null);
	}

	/**
	 * Method to abort current operation
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function cancel($key = NULL)
	{
		$app = Factory::getApplication();

		// Get the current edit id.
		$editId = (int) $app->getUserState('com_raffle.edit.raffle.id');

		// Get the model.
		$model = $this->getModel('Raffleform', 'Site');

		// Check in the item
		if ($editId)
		{
			$model->checkin($editId);
		}

		$menu = Factory::getApplication()->getMenu();
		$item = $menu->getActive();
		$url  = (empty($item->link) ? 'index.php?option=com_raffle&view=raffles' : $item->link);
		$this->setRedirect(Route::_($url, false));
	}

	/**
	 * Method to remove data
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   1.0.0
	 */
	public function remove()
	{
		$app   = Factory::getApplication();
		$model = $this->getModel('Raffleform', 'Site');
		$pk    = $app->input->getInt('id');

		// Attempt to save the data
		try
		{
			$return = $model->delete($pk);

			// Check in the profile
			$model->checkin($return);

			// Clear the profile id from the session.
			$app->setUserState('com_raffle.edit.raffle.id', null);

			$menu = $app->getMenu();
			$item = $menu->getActive();
			$url = (empty($item->link) ? 'index.php?option=com_raffle&view=raffles' : $item->link);

			// Redirect to the list screen
			$this->setMessage(Text::_('COM_RAFFLE_ITEM_DELETED_SUCCESSFULLY'));
			$this->setRedirect(Route::_($url, false));

			// Flush the data from the session.
			$app->setUserState('com_raffle.edit.raffle.data', null);
		}
		catch (\Exception $e)
		{
			$errorType = ($e->getCode() == '404') ? 'error' : 'warning';
			$this->setMessage($e->getMessage(), $errorType);
			$this->setRedirect('index.php?option=com_raffle&view=raffles');
		}
	}
}
