<?php
/**
 * @version    CVS: 1.0.0
 * @package    Com_Raffle
 * @author     David George <david.george@bluelinetechnology.com.au>
 * @copyright  2022 David George
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \Joomla\CMS\Session\Session;

HTMLHelper::addIncludePath(JPATH_COMPONENT . '/helpers/html');
HTMLHelper::_('bootstrap.tooltip');
HTMLHelper::_('behavior.multiselect');
HTMLHelper::_('formbehavior.chosen', 'select');

$user       = Factory::getUser();
$userId     = $user->get('id');
$listOrder  = $this->state->get('list.ordering');
$listDirn   = $this->state->get('list.direction');
$canCreate  = $user->authorise('core.create', 'com_raffle') && file_exists(JPATH_COMPONENT . DIRECTORY_SEPARATOR . 'forms' . DIRECTORY_SEPARATOR . 'raffleform.xml');
$canEdit    = $user->authorise('core.edit', 'com_raffle') && file_exists(JPATH_COMPONENT .  DIRECTORY_SEPARATOR . 'forms' . DIRECTORY_SEPARATOR . 'raffleform.xml');
$canCheckin = $user->authorise('core.manage', 'com_raffle');
$canChange  = $user->authorise('core.edit.state', 'com_raffle');
$canDelete  = $user->authorise('core.delete', 'com_raffle');

// Import CSS
$wa = Factory::getApplication()->getDocument()->getWebAssetManager();
$wa->useStyle('com_raffle.list');
?>

<h1>
Tickets sold: <?php echo ($this->stats->total_tickets) ? $this->stats->total_tickets : 0; ?><br>
Total Raised: $<?php echo ($this->stats->total_raised) ? $this->stats->total_raised : 0; ?>
</h1>

<p>Payment of raffle tickets will be deducted from your pay in the March pay run</p>
<p><strong>1<sup>st</sup> Prize – 2 nights accommodation @ <a href="https://www.hyatt.com/en-US/hotel/australia/hyatt-centric-melbourne/melct/" target="_blank">Hyatt Centric Hotel, Melbourne</a></strong></p>
<p>.(available to all staff – interstate staff will have to purchase their own air fare)</p>
<p><strong>2<sup>nd</sup> Prize - <a href="https://www.prezzee.com.au/" target="_blank">$50 Prezze voucher</a></strong></p>
<p>All proceeds will be donated to <strong>Manoli “Oli” Plueckhahn</strong> through the <a target="_blank" href="https://eur01.safelinks.protection.outlook.com/?url=https%3A%2F%2Ftreat.rarecancers.org.au%2Fcampaign%2F2113%2Fhelping-manoli-oli-plueckhahn&amp;data=04%7C01%7Canna.hill%40servier.com%7Ce64d50490b724fd9d44908d9a1ad95e8%7Ccc0a4ff694544e4b881b85f448dee2e3%7C0%7C0%7C637718589184322421%7CUnknown%7CTWFpbGZsb3d8eyJWIjoiMC4wLjAwMDAiLCJQIjoiV2luMzIiLCJBTiI6Ik1haWwiLCJXVCI6Mn0%3D%7C1000&amp;sdata=%2F%2FGnyA3t3y%2FgKRSQwJmXnenIIKAKkXZNrmCu5helATc%3D&amp;reserved=0">Rare Cancers Australian giving page</a></p>


<form action="<?php echo htmlspecialchars(Uri::getInstance()->toString()); ?>" method="post"
	  name="adminForm" id="adminForm">
    
	<?php 
	/**
	if(!empty($this->filterForm)) { echo LayoutHelper::render('joomla.searchtools.default', array('view' => $this)); } 
	*/
	?>
	
	
	<div class="table-responsive">
		<table class="table table-striped" id="raffleList">
			<thead>
			<tr>
				
					

					<th class=''>
						<?php echo HTMLHelper::_('grid.sort',  'COM_RAFFLE_RAFFLES_NAME', 'a.name', $listDirn, $listOrder); ?>
					</th>

					<th class=''>
						<?php echo HTMLHelper::_('grid.sort',  'COM_RAFFLE_RAFFLES_NUMBER_OF_TICKETS', 'a.number_of_tickets', $listDirn, $listOrder); ?>
					</th>

                    <?php if ($canEdit || $canDelete): ?>
					<th >
						<?php echo HTMLHelper::_('grid.sort', 'JPUBLISHED', 'a.state', $listDirn, $listOrder); ?>
					</th>
					<th class="center">
						<?php echo Text::_('COM_RAFFLE_RAFFLES_ACTIONS'); ?>
					</th>
					<th class=''>
						<?php echo HTMLHelper::_('grid.sort',  'COM_RAFFLE_RAFFLES_ID', 'a.id', $listDirn, $listOrder); ?>
					</th>
                    <?php endif; ?>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
					<?php echo $this->pagination->getListFooter(); ?>
				</td>
			</tr>
			</tfoot>
			<tbody>
			<?php foreach ($this->items as $i => $item) : ?>
				<?php $canEdit = $user->authorise('core.edit', 'com_raffle'); ?>
				<?php if (!$canEdit && $user->authorise('core.edit.own', 'com_raffle')): ?>
				<?php $canEdit = Factory::getUser()->id == $item->created_by; ?>
				<?php endif; ?>

				<tr class="row<?php echo $i % 2; ?>">
					
					
					<td>
						<?php $canCheckin = Factory::getUser()->authorise('core.manage', 'com_raffle.' . $item->id) || $item->checked_out == Factory::getUser()->id; ?>
						<?php if($canCheckin && $item->checked_out > 0) : ?>
							<a href="<?php echo Route::_('index.php?option=com_raffle&task=raffle.checkin&id=' . $item->id .'&'. Session::getFormToken() .'=1'); ?>">
							<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'raffle.', false); ?></a>
						<?php endif; ?>
						<a href="<?php echo Route::_('index.php?option=com_raffle&view=raffle&id='.(int) $item->id); ?>">
							<?php echo $this->escape($item->name); ?></a>
					</td>
					<td>
						<?php echo $item->number_of_tickets; ?>
					</td>
					<?php if ($canEdit || $canDelete): ?>
					<td>
						<?php $class = ($canChange) ? 'active' : 'disabled'; ?>
						<a class="btn btn-micro <?php echo $class; ?>" href="<?php echo ($canChange) ? JRoute::_('index.php?option=com_raffle&task=raffle.publish&id=' . $item->id . '&state=' . (($item->state + 1) % 2), false, 2) : '#'; ?>">
						<?php if ($item->state == 1): ?>
							<i class="icon-publish"></i>
						<?php else: ?>
							<i class="icon-unpublish"></i>
						<?php endif; ?>
						</a>
					</td>
						<td class="center">
							<?php $canCheckin = Factory::getUser()->authorise('core.manage', 'com_raffle.' . $item->id) || $this->item->checked_out == Factory::getUser()->id; ?>

							<?php if($canEdit && $item->checked_out == 0): ?>
								<a href="<?php echo Route::_('index.php?option=com_raffle&task=raffle.edit&id=' . $item->id, false, 2); ?>" class="btn btn-mini" type="button"><i class="icon-edit" ></i></a>
							<?php endif; ?>
							<?php if ($canDelete): ?>
								<a href="<?php echo Route::_('index.php?option=com_raffle&task=raffleform.remove&id=' . $item->id, false, 2); ?>" class="btn btn-mini delete-button" type="button"><i class="icon-trash" ></i></a>
							<?php endif; ?>
						</td>
					
                    <td>
						<?php echo $item->id; ?>
					</td>
					<?php endif; ?>
				</tr>
			<?php endforeach; ?>
			</tbody>
		</table>
	</div>
	<?php if ($canCreate) : ?>
		<a href="<?php echo Route::_('index.php?option=com_raffle&task=raffleform.edit&id=0', false, 0); ?>"
		   class="btn btn-success btn-block btn-small"><i
				class="icon-plus"></i>
			<?php echo Text::_('Buy Tickets'); ?></a>
	<?php endif; ?>

	<input type="hidden" name="task" value=""/>
	<input type="hidden" name="boxchecked" value="0"/>
	<input type="hidden" name="filter_order" value=""/>
	<input type="hidden" name="filter_order_Dir" value=""/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<?php
	if($canDelete) {
		$wa->addInlineScript("
			jQuery(document).ready(function () {
				jQuery('.delete-button').click(deleteItem);
			});

			function deleteItem() {

				if (!confirm(\"" . Text::_('COM_RAFFLE_DELETE_MESSAGE') . "\")) {
					return false;
				}
			}
		", [], [], ["jquery"]);
	}
?>